@@ -28,10 +28,10 @@ class JpegCreator : public ThumbCreatorV2
 {
 public:
     JpegCreator();
-    virtual bool create(const QString &path, int, int, QImage &img);
-    virtual Flags flags() const;
-    virtual QWidget *createConfigurationWidget();
-    virtual void writeConfiguration(const QWidget *configurationWidget);
+    bool create(const QString &path, int, int, QImage &img) override;
+    Flags flags() const override;
+    QWidget *createConfigurationWidget() override;
+    void writeConfiguration(const QWidget *configurationWidget) override;
 };
 
 #endif
